# coding: utf-8

import requests
from bs4 import BeautifulSoup
import lazyf1images

class F1News(object):

	headers = {'user-agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/57.0.2987.100 Safari/537.36',
				'upgrade-insecure-requests':'1'}

	champ_soaps = {}

	tracks_path = lazyf1images.tracks()

	track_map = {"ru-f1news": 
		{u"Альберт-парк":"melbourne",
		u"Мельбурн":"melbourne",
		u"Шанхай":"shanghai",
		u"Сахир":"sakhir",
		u"Сочи":"sochi",
		u"Барселона":"barcelona",
		u"Монте-Карло":"monaco",
		u"Монреаль":"montreal",
		u"Баку":"baku",
		u"Ред Булл Ринг":"redbullring",
		u"Шпильберг":"redbullring",
		u"Сильверстоун":"silverstone",
		u"Хунгароринг":"hungaroring",
		u"Будапешт":"hungaroring",
		u"Хоккенхайм":"hockenheim",
		u"Нюрбургринг":"nuerburgring",
		u"Спа":"spa",
		u"Монца":"monza",
		u"Марина-Бей":"singapore",
		u"Сингапур":"singapore",
		u"Сепанг":"sepang",
		u"Сузука":"suzuka",
		u"Остин":"austin",
		u"Мехико":"mexico",
		u"Сан-Паулу":"interlagos",
		u"Яс-Марина":"yasmarina"
		}
	}


	def __init__(self, *args, **kwargs):
		self.root_soap = self._get_root_soap()
		return super(F1News, self).__init__(*args, **kwargs)

	def _get_root_soap(self):
		resp = requests.get('https://www.f1news.ru', headers=self.headers, verify=False)
		if resp.status_code == requests.codes.ok:
			html = resp.text
			soup = BeautifulSoup(html, 'html.parser')
			return soup

	def _get_champ_soap(self, year):
		resp = requests.get('https://www.f1news.ru/Championship/%s/' % str(year), headers=self.headers, verify=False)
		if resp.status_code == requests.codes.ok:
			html = resp.text
			soup = BeautifulSoup(html, 'html.parser')
			return soup

	def champ_soap(self, year):
		year = str(year)
		if year not in self.champ_soaps:
			self.champ_soaps[year] = self._get_champ_soap(year)

		return self.champ_soaps.get(year)

	@property
	def curr_champ_soap(self, year):
		return self.champ_soap(2017)

	def weekend_title(self):
		if self.root_soap:
			return self.root_soap.select('div.widget.stream.widget_danger > div.widget_head > div > span')[0].get_text()

	def weekend_schedule(self, get_url):
		if self.root_soap:
			for a in self.root_soap.find_all('a', class_='red', attrs={'href': '/lc/'}):
				tr = a.parent.parent
				title = tr.find('span').get_text()
				yield {'label': title, 'thumb': '', 'is_playable': True, 
						'url': get_url(action='search', event=title.encode('utf-8'), season='2017', GP=self.weekend_title().encode('utf-8'))}

	def calendar(self, year, get_url):
		year = str(year)
		soap = self.champ_soap(year)
		if soap:

			for tr in soap.find('table', class_='f1Table').find_all('tr'):
				if 'firstLine' in tr['class']:
					continue

				TDs = tr.find_all('td')				

				item = {'is_playable': False}
				item['label'] = u'%s %s (%s)' % (TDs[0].get_text(), TDs[2].get_text(), TDs[3].get_text())
				try:
					ru = TDs[3].get_text()
					if ru in self.track_map['ru-f1news']:
						item['thumb'] = self.tracks_path + self.track_map['ru-f1news'][ru] + '/map.png'
						item['fanart'] = self.tracks_path + self.track_map['ru-f1news'][ru] + '/bg.jpg'
					else:
						import urlparse
						res = urlparse.urlparse(TDs[1].img['src'])
						res = urlparse.ParseResult(res.scheme if res.scheme else 'https', res.netloc, res.path, res.params, res.query, res.fragment)
						item['thumb'] = urlparse.urlunparse(res)  
				except:
					pass
				item['url'] = get_url(action='show_gp', season=str(year), GP=TDs[2].get_text().encode('utf-8'))

				yield item
